package xyz.wbsite.dbtool.javafx.manger.callable;

import xyz.wbsite.dbtool.javafx.manger.FreeMarkerManager;
import xyz.wbsite.dbtool.javafx.manger.ManagerFactory;
import xyz.wbsite.dbtool.javafx.manger.ProjectManager;
import xyz.wbsite.dbtool.javafx.po.AbstractDBmapper;
import xyz.wbsite.dbtool.javafx.po.AndroidOption;
import xyz.wbsite.dbtool.javafx.po.VueOption;
import xyz.wbsite.dbtool.javafx.tool.Tool;

import javax.validation.constraints.NotNull;
import java.io.File;
import java.util.HashMap;
import java.util.concurrent.Callable;
import java.util.regex.Matcher;

import static xyz.wbsite.dbtool.javafx.tool.Tool.clear;

public class VueCallable implements Callable {

    private String path;
    private VueOption option;

    private FreeMarkerManager freeMarkerManager;

    public VueCallable(@NotNull String path, VueOption option) {
        this.path = path;
        this.option = option;
        this.freeMarkerManager = ManagerFactory.getFreeMarkerManager();
    }

    private AbstractDBmapper dBmapper;

    public Boolean call() throws Exception {
        File app = new File(path, option.projectName);
        if (!app.exists()) {
            app.mkdirs();
        } else {
            clear(app);
        }

        // 目录生成
        File src = new File(app, "src");
        src.mkdirs();
        File assets = new File(src, "assets");
        assets.mkdirs();
        File components = new File(src, "components");
        components.mkdirs();
        File plugins = new File(src, "plugins");
        plugins.mkdirs();
        File publics = new File(app, "public");
        publics.mkdirs();

        {
            HashMap<String, Object> ctx = new HashMap<String, Object>();
            ctx.put("appName", option.projectName);
            ctx.put("elementui", option.elementui);
            ctx.put("iView", option.iView);
            freeMarkerManager.outputTemp(new File(app, "package.json"), "Vue/package.json", ctx);
            freeMarkerManager.outputTemp(new File(app, "package-lock.json"), "Vue/package-lock.json", ctx);
            freeMarkerManager.outputTemp(new File(app, "README.md"), "Vue/README.md", ctx);
            Tool.outputResource("Vue/babel.config.js", new File(app, "babel.config.js"));

            //public
            Tool.outputResource("Vue/public/favicon.ico", new File(publics, "favicon.ico"));
            freeMarkerManager.outputTemp(new File(app, "index.html"), "Vue/public/index.html", ctx);

            //src
            freeMarkerManager.outputTemp(new File(src, "App.vue"), "Vue/src/App.vue", ctx);
            freeMarkerManager.outputTemp(new File(src, "main.js"), "Vue/src/main.js", ctx);
            Tool.outputResource("Vue/src/router.js", new File(src, "router.js"));
            Tool.outputResource("Vue/src/assets/logo.png", new File(assets, "logo.png"));
            Tool.outputResource("Vue/src/components/HelloWorld.vue", new File(components, "HelloWorld.vue"));
            if (option.elementui) {
                Tool.outputResource("Vue/src/plugins/element.js", new File(plugins, "element.js"));
            }
            if (option.iView) {
                Tool.outputResource("Vue/src/plugins/iview.js", new File(plugins, "iview.js"));
            }
        }

        return true;
    }
}
